.. _verifier:

Verifier
========

Base
----

.. autoclass:: molecule.verifier.base.Base
   :members:

Goss
----

.. autoclass:: molecule.verifier.goss.Goss
   :members:

Serverspec
----------

.. autoclass:: molecule.verifier.serverspec.Serverspec
   :members:

Testinfra
---------

.. autoclass:: molecule.verifier.testinfra.Testinfra
   :members:

Trailing
--------

.. autoclass:: molecule.verifier.trailing.Trailing
   :members:
